@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012, the codeeditor development team
+# Copyright (C) 2013, the codeeditor development team
 #
 # IEP is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
@@ -127,6 +127,10 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
     # Signal emitted after font (or font size) has changed
     fontChanged = QtCore.Signal()
     
+    # Signal to indicate a change in breakpoints. Only emitted if the
+    # appropriate extension is in use
+    breakPointsChanged = QtCore.Signal(object)
+    
     
     def __init__(self,*args, **kwds):
         super(CodeEditorBase, self).__init__(*args)
@@ -157,6 +161,9 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
         self.styleChanged.connect(self.__afterSetStyle)
         self.__styleChangedPending = False
         
+        # Init margins
+        self._leftmargins = []
+        
         # Init options now. 
         # NOTE TO PEOPLE DEVELOPING EXTENSIONS:
         # If an extension has an __init__ in which it first calls the 
@@ -362,23 +369,34 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
         
         """
         
-        # Check
+        defaultFont = Manager.defaultFont()
+        
+        # Get font object
         if font is None:
-            font = Manager.defaultFont().family()
+            font = defaultFont
         elif isinstance(font, QtGui.QFont):
-            font = font.family()
-        elif isinstance(font, str):
             pass
+        elif isinstance(font, str):
+            font = QtGui.QFont(font)
         else:
             raise ValueError("setFont accepts None, QFont or string.")
         
-        # Set size: default size + zoom
-        size = Manager.defaultFont().pointSize() + self.__zoom
-        font = QtGui.QFont(font, size)
-        
-        # Make sure it's monospace
+        # Hint Qt that it should be monospace
         font.setStyleHint(font.TypeWriter, font.PreferDefault)
         
+        # Get family, fall back to default if qt could not produce monospace
+        fontInfo = QtGui.QFontInfo(font)
+        if fontInfo.fixedPitch():
+            family = fontInfo.family() 
+        else:
+            family = defaultFont.family()
+        
+        # Get size: default size + zoom
+        size = defaultFont.pointSize() + self.__zoom
+        
+        # Create font instance
+        font = QtGui.QFont(family, size)
+        
         # Set, emit and return
         QtGui.QPlainTextEdit.setFont(self, font)
         self.fontChanged.emit()
@@ -402,7 +420,7 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
         self.setFont(self.fontInfo().family())
         # Return zoom
         return self.__zoom
-        
+    
     
     ## Syntax / styling
     
@@ -617,7 +635,10 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
         cursor.movePosition(cursor.Start) # move to begin of the document
         cursor.movePosition(cursor.NextBlock,n=blockNumber) # n blocks down
         
-        self.setTextCursor(cursor)
+        try:
+            self.setTextCursor(cursor)
+        except Exception:
+            pass # File is smaller then the caller thought
         self.centerCursor()
     
     def doForSelectedBlocks(self, function):
@@ -662,7 +683,34 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
             
         editCursor.endEditBlock()
     
-    
+    def doForVisibleBlocks(self, function):
+        """ doForVisibleBlocks(function)
+        
+        Call the given function(cursor) for all blocks that are currently
+        visible. This is used by several appearence extensions that
+        paint per block.
+        
+        The supplied cursor will be located at the beginning of each block. This
+        cursor may be modified by the function as required
+        
+        """
+
+        # Start cursor at top line.
+        cursor = self.cursorForPosition(QtCore.QPoint(0,0))
+        cursor.movePosition(cursor.StartOfBlock)
+
+        while True:            
+            # Call the function with a copy of the cursor
+            function(QtGui.QTextCursor(cursor))
+            
+            # Go to the next block (or not if we are done)
+            y = self.cursorRect(cursor).bottom() 
+            if y > self.height():
+                break #Reached end of the repaint area
+            if not cursor.block().next().isValid():
+                break #Reached end of the text
+            cursor.movePosition(cursor.NextBlock)
+        
     def indentBlock(self, cursor, amount=1):
         """ indentBlock(cursor, amount=1)
         
@@ -758,3 +806,32 @@ class CodeEditorBase(QtGui.QPlainTextEdit):
         # Update the selection
         #self.setTextCursor(cursor) for testing
         cursor.insertText(newText)
+    
+    
+    def addLeftMargin(self, des, func):
+        """ Add a margin to the left. Specify a description for the margin,
+        and a function to get that margin. For internal use.
+        """
+        assert des is not None
+        self._leftmargins.append((des, func))
+    
+    
+    def getLeftMargin(self, des=None):
+        """ Get the left margin, relative to the given description (which
+        should be the same as given to addLeftMargin). If des is omitted 
+        or None, the full left margin is returned.
+        """
+        margin = 0
+        for d, func in self._leftmargins:
+            if d == des:
+                break
+            margin += func()
+        return margin
+    
+    
+    def updateMargins(self):
+        """ Force the margins to be recalculated and set the viewport 
+        accordingly.
+        """
+        leftmargin = self.getLeftMargin()
+        self.setViewportMargins(leftmargin , 0, 0, 0)
