@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012, the IEP development team
+# Copyright (C) 2013, the IEP development team
 #
 # IEP is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
@@ -15,10 +15,11 @@ file loading/saving /reloading stuff.
 import os, sys
 import re, codecs
 
-from iep.codeeditor.qt import QtCore, QtGui
+from pyzolib.qt import QtCore, QtGui
 qt = QtGui
 
 from iep.codeeditor import Manager
+from iep.iepcore.menu import EditorContextMenu
 from iep.iepcore.baseTextCtrl import BaseTextCtrl, normalizePath
 from iep.iepcore.iepLogging import print
 import iep
@@ -76,10 +77,10 @@ def determineEncoding(bb):
 def determineLineEnding(text):
     """ Get the line ending style used in the text.
     \n, \r, \r\n,
-    The EOLmode is determined by counting the occurances of each
+    The EOLmode is determined by counting the occurrences of each
     line ending...    
     """
-    # test line ending by counting the occurances of each
+    # test line ending by counting the occurrence of each
     c_win = text.count("\r\n")
     c_mac = text.count("\r") - c_win
     c_lin = text.count("\n") - c_win
@@ -263,7 +264,6 @@ class IepEditor(BaseTextCtrl):
         # dito for zoom and tabWidth
         
         
-        
         # Set line endings to default
         self.lineEndings = iep.config.settings.defaultLineEndings
         
@@ -280,6 +280,12 @@ class IepEditor(BaseTextCtrl):
         
         # This timer is used to hide the marker that shows which code is executed
         self._showRunCursorTimer = QtCore.QTimer()
+        
+        # Add context menu (the offset is to prevent accidental auto-clicking)
+        self._menu = EditorContextMenu(self)
+        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.customContextMenuRequested.connect(lambda p: self._menu.popup(self.mapToGlobal(p)+QtCore.QPoint(0,3))) 
+    
     
     ## Properties
     
@@ -440,15 +446,10 @@ class IepEditor(BaseTextCtrl):
         
         # compose title
         name, path = self._name, self._filename
-        if not path:
-            path = 'no location on disk'
-        tmp = { 'fileName':name, 'filename':name, 'name':name,
-                'fullPath':path, 'fullpath':path, 'path':path }
-        title = iep.config.advanced.titleText.format(**tmp)
-        
-        # set title
-        iep.main.setWindowTitle(title)
-    
+        if path:
+            iep.main.setMainTitle(path)
+        else:
+            iep.main.setMainTitle(name)
     
     
     def save(self, filename=None):
